| Title: | Human Protein Atlas in R |
|---|---|
| Description: | The hpar package provides a simple R interface to and data from the Human Protein Atlas project. |
| Authors: | Laurent Gatto [cre, aut] (ORCID: <https://orcid.org/0000-0002-1520-2268>), Manon Martin [aut] |
| Maintainer: | Laurent Gatto <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 1.55.0 |
| Built: | 2026-05-30 09:32:50 UTC |
| Source: | https://github.com/bioc/hpar |
Browser the HPA page for a gene.
browseHPA(id)browseHPA(id)
id |
A 'character()' with one or multipel Ensembl gene identifiers. |
Returns the URL(s) for the provided gene identifiers. If interactive, opens the URL(s).
Laurent Gatto
browseHPA("ENSG00000163435")browseHPA("ENSG00000163435")
Obtain the data and release information of the Human Protein Atlas (HPA) sets distributed by 'hpar'. See http://www.proteinatlas.org/about/releases for the HPA release history.
getHpaDate()getHpaDate()
A 'character()' with the release information.
Laurent Gatto
allHparData() getHpaVersion() getHpaDate() getHpaEnsembl()allHparData() getHpaVersion() getHpaDate() getHpaEnsembl()